@@ -64,7 +64,7 @@ def create_task(celery_app, **task_kwargs):
         for step_event in execute_plan_iterator(
             execution_plan=execution_plan,
             pipeline=pipeline,
-            pipeline_run=pipeline_run,
+            dagster_run=pipeline_run,
             instance=instance,
             retry_mode=retry_mode,
             run_config=pipeline_run.run_config,
